summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/transfor.h
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/transfor.h')
-rw-r--r--crawl-ref/source/transfor.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/crawl-ref/source/transfor.h b/crawl-ref/source/transfor.h
index 33df1c6b37..5dff88bcfa 100644
--- a/crawl-ref/source/transfor.h
+++ b/crawl-ref/source/transfor.h
@@ -49,8 +49,9 @@ void unmeld_one_equip(equipment_type eq);
bool transform_changed_physiology( bool phys_scales = false );
bool transform_allows_wearing_item(const item_def& item,
transformation_type transform);
// Check your current transform
bool transform_allows_wearing_item(const item_def& item);
bool transform_allows_wielding(transformation_type transform);
+void transformation_expiration_warning();
#endif
@@ -49,8 +49,9 @@ void unmeld_one_equip(equipment_type eq);
bool transform_allows_wearing_item(const item_def& item,
transformation_type transform);
-// Check your current transform
+// Check your current transformation.
bool transform_allows_wearing_item(const item_def& item);
bool transform_allows_wielding(transformation_type transform);